@@ -144,8 +144,8 @@ final class CGCalendar extends CGExtensions
   function HasAdmin() { return true; }  
   function GetEventDescription( $eventname ) { return $this->lang('eventdesc-' . $eventname); }
   function GetEventHelp( $eventname ) {	return $this->lang('eventhelp-' . $eventname); }
-  function GetVersion() { return '1.11.4.1'; }
-  function GetDependencies() { return array('CGExtensions'=>'1.32.3'); }
+  function GetVersion() { return '1.13.1'; }
+  function GetDependencies() { return array('CGExtensions'=>'1.37.3'); }
   function GetDescription($lang = 'en_US') { return $this->Lang("description"); }
   function GetAdminDescription() { return $this->Lang('cal_description'); }
   function GetAdminSection() { return 'content'; }
@@ -170,6 +170,8 @@ final class CGCalendar extends CGExtensions
   function VisibleToAdminUser()
   {
 	return $this->CheckPermission('Modify Calendar') ||
+	  $this->CheckPermission('Add Calendar Events') ||
+	  $this->CheckPermission('Edit My Calendar Events') ||
 	  $this->CheckPermission('Manage Calendar Attributes') ||
 	  $this->CheckPermission('Modify Site Preferences') ||
 	  $this->CheckPermission('Modify Templates');
@@ -386,33 +388,17 @@ final class CGCalendar extends CGExtensions
 	return self::$_cached_categories;
   }
 
-  function AllowAccess($permission='Modify Calendar')
-  {
-	$access = $this->CheckPermission($permission);
-	if (!$access)  {
-	  echo '<p class="error">'.$this->Lang('error_permission',$permission).'</p>';
-	  return false;
-	}
-	return true;
-  }
-
-  function LoadAdmin()
+  private function _LoadAdmin()
   {
 	if( $this->admin_tools_loaded === false ) require_once('functions.admin_tools.php');
   }
 
   function AdminDisplayCategories($id, &$parameters, $returnid)
   {
-	$this->LoadAdmin();
+	$this->_LoadAdmin();
 	return calendar_AdminDisplayCategories($this,$id,$parameters,$returnid);
   }
 
-  function AdminDeleteEvent($id, &$parameters, $returnid)
-  {
-	$this->LoadAdmin();
-	return calendar_AdminDeleteEvent($this,$id,$parameters,$returnid);
-  }
-
   function GetFields()
   {
 	if( !is_array(self::$_cached_fields) ) {
@@ -520,14 +506,14 @@ final class CGCalendar extends CGExtensions
 
   function isValidFilename($filename)
   {
-      $this->LoadAdmin();
+      $this->_LoadAdmin();
       return calendar_isValidFilename($this,$filename);
   }
 
 
   function HandleUpload($fldname,&$error)
   {
-      $this->LoadAdmin();
+      $this->_LoadAdmin();
       return calendar_HandleUpload($this,$fldname,$error);
   }
 
@@ -559,10 +545,9 @@ final class CGCalendar extends CGExtensions
       $destpage = $this->GetPreference('defaultcalendarpage',-1);
       $destpage=$destpage!=-1?$destpage:$returnid;
       $destpage=$detailpage!=''?$detailpage:$destpage;
-      $prettyurl = sprintf($this->GetPreference('url_prefix','calendar')."/%d/%d-%s",
-						   $destpage,$event_id,$titleSEO);
+      $prettyurl = sprintf($this->GetPreference('url_prefix','calendar')."/%d/%d-%s", $destpage,$event_id,$titleSEO);
       $result[2] = $this->CreateLink($id,'default',$destpage,'',
-				     array('event_id'=>$event_id,'display'=>'event','detailpage'=>$destpage,'return_id'=>$returnid),
+									 array('event_id'=>$event_id,'display'=>'event','detailpage'=>$destpage,'return_id'=>$returnid),
 									 '', true, '', '', $prettyurl);
       return $result;
   }
@@ -649,4 +634,4 @@ final class CGCalendar extends CGExtensions
   }
 
 }; // class
-?>
+?>
\ No newline at end of file
