@@ -35,18 +35,32 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
+if( !isset($gCms) ) exit;
 $this->SetCurrentTab('defaultadmin');
 
-if( !$this->AllowAccess() )
-{
-  return;
-}
-
-$db = $this->GetDb(); /* @var $db ADOConnection */
-$categories = $this->GetCategories();
 // Get the event
 $event_id = get_parameter_value($params, 'event_id', -1);
 $event = $this->GetEvent($event_id);
+$user_id = get_userid() * -1 - 100;
+
+// permissions check
+if( $event_id < 1 ) {
+  // adding
+  if( !$this->CheckPermission('Modify Calendar') && !$this->CheckPermission('Add Calendar Events') ) {
+    $this->SetError($this->Lang('error_permission'));
+    $this->RedirectToAdminTab();
+  }
+}
+else {
+  // editing
+  if( !$this->CheckPermission('Modify Calendar') && 
+      !($this->CheckPermission('Edit My Calendar Events') && $event['event_created_by'] == $user_id) ) {
+    $this->SetError($this->Lang('error_permission'));
+    $this->RedirectToAdminTab();
+  }
+}
+
+$categories = $this->GetCategories();
 if( isset($params['do_get_from_params']) && $params['do_get_from_params'] == 1 ) {
   $this->GetEventFromParams($event,$params);
 }
@@ -56,10 +70,7 @@ $smarty->assign('event',$event);
 $fields = $this->GetFields();
 
 $button_text = $this->Lang('cal_add');
-if($event_id > 0)
-{
-	$button_text = $this->Lang('cal_update');
-}
+if($event_id > 0) $button_text = $this->Lang('cal_update');
 
 $extra="";
 if ($this->GetPreference("force_category")==1) {
@@ -76,25 +87,15 @@ $smarty->assign('start_year',$start);
 $smarty->assign('end_year',$end);
 
 $event_date_start_ut = time();
-if(isset($params['startdate_Hour']))
-{
-  $event_date_start_ut = mktime($params['startdate_Hour'],
-				$params['startdate_Minute'],
-				0,
-				$params['startdate_Month'],
-				$params['startdate_Day'],
-				$params['startdate_Year']);
+if(isset($params['startdate_Hour'])) {
+  $event_date_start_ut = mktime($params['startdate_Hour'],$params['startdate_Minute'],0,
+				$params['startdate_Month'],$params['startdate_Day'],$params['startdate_Year']);
 }
 
 $event_date_end_ut = 0;
-if(isset($params['enddate_Hour']))
-{
-  $event_date_end_ut = mktime($params['enddate_Hour'],
-				$params['enddate_Minute'],
-				59,
-				$params['enddate_Month'],
-				$params['enddate_Day'],
-				$params['enddate_Year']);
+if(isset($params['enddate_Hour'])) {
+  $event_date_end_ut = mktime($params['enddate_Hour'],$params['enddate_Minute'],59,
+			      $params['enddate_Month'],$params['enddate_Day'],$params['enddate_Year']);
 }
 
 $event_recur_period = 'none';
@@ -149,24 +150,21 @@ $weekdays = array($this->Lang('sunday')=>'0',
 		  $this->Lang('saturday')=>'6');
 $tmp = array();
 $smarty->assign('input_weekdays',
-		$this->CreateInputSelectList($id,'event_recur_weekdays[]',$weekdays,
-					     $event['event_recur_weekdays'],7));
+		$this->CreateInputSelectList($id,'event_recur_weekdays[]',$weekdays,$event['event_recur_weekdays'],7));
 $smarty->assign('repeat_str',$this->Lang('plural_'.$event['event_recur_period']));
 $smarty->assign('weekdays',$weekdays);
 $nums = array();
 $nums[-1] = $this->Lang('unlimited');
-for( $i = 0; $i < 50; $i++ )
-  {
-    $nums[$i+1] = $i+1;
-  }
+for( $i = 0; $i < 50; $i++ ) {
+  $nums[$i+1] = $i+1;
+}
 $nums[100] = 100;
 $nums[250] = 250;
 $smarty->assign('maxiters',$nums);
 $nums = array();
-for( $i = 0; $i < 30; $i++ )
-  {
-    $nums[$i+1] = $i+1;
-  }
+for( $i = 0; $i < 30; $i++ ) {
+  $nums[$i+1] = $i+1;
+}
 $smarty->assign('nums',$nums);
 $smarty->assign('recur_options',
 		array($this->Lang('no')=>"none",
@@ -176,10 +174,7 @@ $smarty->assign('recur_options',
 		      $this->Lang('yearly')=>'yearly'));
 $smarty->assign('event_recur_period',$event_recur_period);
 
-if( $this->GetPreference('overlap_policy','all') == 'individual' )
-  {
-    $smarty->assign('allow_overlap',1);
-  }
+if( $this->GetPreference('overlap_policy','all') == 'individual' ) $smarty->assign('allow_overlap',1);
 
 $smarty->assign('event_title',$this->CreateInputText($id, 'event_title', $event['event_title'], 50, 255));
 
@@ -189,16 +184,12 @@ if ($this->GetPreference("hidesummary")!=1) {
 
 // Add input controls for each of the custom fields that are defined.
 $tmp = array();
-foreach($fields as $field) 
-{
+foreach($fields as $field) {
   $field_values = $event['fields'];
   $field_name = $field['field_name'];
   $field_type = $field['field_type'];
   $field_value = "";
-  if( isset($field_values[$field_name]) )
-    {
-      $field_value = $field_values[$field_name];
-    }
+  if( isset($field_values[$field_name]) ) $field_value = $field_values[$field_name];
 
   // Replace spaces with underbars for the form parameter (a bit of an ikky hack I know, 
   // but I can well imagine folk defining custom fields with spaces in the name) 
@@ -209,11 +200,11 @@ foreach($fields as $field)
   $obj->name = $field['field_name'];
   $obj->value = $field_value;
   $obj->type = $field['field_type'];
-  switch( $field_type )
-    {
+  switch( $field_type ) {
     case 0: // the normal text field
       $obj->field = $this->CreateInputText($id, 'field_'.$safefieldname, $field_value, 50, 255);
       break;
+
     case 1: // an upload field type
       // display a label with the current value, and then an upload field
       $obj->value = $field_value;
@@ -221,7 +212,7 @@ foreach($fields as $field)
 	$this->CreateInputHidden($id,'upload_field_'.$safefieldname,$field_name).
 	$this->CreateInputHidden($id,'upload_field_oldvalue_'.$safefieldname,$field_value);
       if( $field_value ) $obj->field .=
-	$this->CreateInputHidden($id,'remove_field_'.$safefiledname,0).
+	$this->CreateInputHidden($id,'remove_field_'.$safefieldname,0).
 	$this->CreateInputCheckbox($id,'remove_field_'.$safefieldname,1).'&nbsp;'.$this->Lang('delete');
       break;
 
@@ -234,44 +225,56 @@ foreach($fields as $field)
     case 3:
       // company directory entry.
       $cdmod = cms_utils::get_module('CompanyDirectory');
-      if( !$cdmod )
-	{
-	  // have field type, but no companydirectory module.
-	  continue;
-	}
+      if( !$cdmod ) {
+	// have field type, but no companydirectory module.
+	continue;
+      }
       // get a list of the companies that we want to display
       {
 	$query = 'SELECT id,company_name FROM '.cms_db_prefix().'module_compdir_companies ORDER BY company_name';
 	$dbr = $db->GetArray($query);
-	if( $dbr )
-	  {
-	    $tmp2 = array($this->Lang('none')=>-1);
-	    for( $i = 0; $i < count($dbr); $i++ )
-	      {
-		$tmp2[$dbr[$i]['company_name']] = $dbr[$i]['id'];
-	      }
-	    $obj->field = $this->CreateInputDropdown($id,'field_'.$safefieldname,$tmp2,-1,$field_value);
+	if( $dbr ) {
+	  $tmp2 = array($this->Lang('none')=>-1);
+	  for( $i = 0; $i < count($dbr); $i++ ) {
+	    $tmp2[$dbr[$i]['company_name']] = $dbr[$i]['id'];
 	  }
+	  $obj->field = $this->CreateInputDropdown($id,'field_'.$safefieldname,$tmp2,-1,$field_value);
+	}
       }
       break;
+
+  case 4:
+    // file attachment
+    $dir = $this->GetPreference('uploaddirectory',$config['uploads_path']);
+    $pattern = explode(',',$this->GetPreference('uploadfiletypes','jpg,jpeg,gif,png'));
+    $excludes = array('_*','.??*');
+    foreach( $pattern as &$one ) {
+      $one = '*.'.$one;
     }
+    $files = cge_dir::recursive_glob($dir,$pattern,'FILES',$excludes);
+    if( !is_array($files) || count($files) == 0 ) continue;
+    
+    $out = array($this->Lang('none')=>-1);
+    foreach( $files as $one ) {
+      $one = substr($one,strlen($dir));
+      if( startswith($one,'/') ) $one = substr($one,1);
+      $out[$one] = $one;
+    }
+    $obj->field = $this->CreateInputDropdown($id,'field_'.$safefieldname,$out,-1,$field_value);
+    break;
+  }
   $tmp[] = $obj;
 }
-if( count($tmp) )
-  {
-    $smarty->assign('fields',$tmp);
-  }
+if( count($tmp) ) $smarty->assign('fields',$tmp);
 
 if ($this->GetPreference("hidecontent")!=1) {
-  $smarty->assign('event_details',
-		  $this->CreateTextArea(true, $id, $event['event_details'], 'event_details', 'content', $id));
+  $smarty->assign('event_details', $this->CreateTextArea(true, $id, $event['event_details'], 'event_details', 'content', $id));
 }
 
 $num_cats = count($categories);
 $count = 0;
 $tmp = array();
-for($i = 0; $i < $num_cats; $i++,$count ++)
-{
+for($i = 0; $i < $num_cats; $i++,$count ++) {
   $category = $categories[$i];
   $cat_id = $category['category_id'];
   $cat_name = $category['category_name'];
@@ -281,10 +284,7 @@ for($i = 0; $i < $num_cats; $i++,$count ++)
   
   //Only tag the default-category is you are adding an event, not it you are editing
   if ($event_id==-1) {
-    if($cat_id == $this->GetPreference('default_category', ''))
-      {
-	$checked = $cat_id;
-      }
+    if($cat_id == $this->GetPreference('default_category', '')) $checked = $cat_id;
   } else {
     if(in_array($cat_id, $event['categories']))	$checked = $cat_id;
   }
@@ -293,10 +293,7 @@ for($i = 0; $i < $num_cats; $i++,$count ++)
   $obj->name = $cat_name;
   $tmp[] = $obj;
 }
-if( count($tmp) )
-  {
-    $smarty->assign('categories',$tmp);
-  }
+if( count($tmp) ) $smarty->assign('categories',$tmp);
 
 $smarty->assign('submit',$this->CreateInputSubmit($id,'submit',$button_text));
 $smarty->assign('cancel',$this->CreateInputSubmit($id,'cancel',$this->Lang('cancel')));
