@@ -35,12 +35,8 @@
 #
 #-------------------------------------------------------------------------
 #END_LICENSE
-if( !$this->AllowAccess() )
-{
-	return;
-}
-
-// TODO: smartyfy
+if( !isset($gCms) ) exit;
+if( !$this->CheckPermission('Modify Calendar') ) return;
 
 $smarty->assign('formstart',$this->CreateFormStart($id, 'admin_import_events', $returnid, 'post', 'multipart/form-data'));
 $smarty->assign('formend',$this->CreateFormEnd());
