@@ -37,22 +37,32 @@
 #END_LICENSE
 if (!isset($gCms)) die();
 
+$this->SetCurrentTab('defaultadmin');
+
 $event_ids = array();
-if( isset($params['tag']) ) {
-  $event_ids = $params['tag'];
-}
+if( isset($params['tag']) ) $event_ids = $params['tag'];
+
 if( count($event_ids) == 0 ) {
-  $this->Redirect($id,"defaultadmin",$returnid,
-		  array("module_error"=>$this->Lang("error_nothingselected")));
+  $this->SetError($this->Lang('error_nothingselected'));
+  $this->RedirectToAdminTab();
 }
 
+$ndeleted = 0;
 foreach( $event_ids as $event_id )
 {
-  $parms = array();
-  $parms['event_id'] = (int)$event_id;
-  $this->AdminDeleteEvent($id,$parms,$returnid);
+  $res = cgcalendar_utils::delete_event($event_id);
+  if( $res ) $ndeleted++;
 }
 
-$this->Redirect($id,"defaultadmin",$returnid,array("module_message"=>$this->Lang("taggeddeleted")));
+if( $ndeleted == 0 ) {
+  $this->SetError($this->Lang('error_nonedeleted')
+}
+else if( $ndeleted < count($event_ids) ) {
+  $this->SetError($this->Lang('error_somedeleted')
+}
+else {
+  $this->SetMessage(4this->Lang('taggeddeleted');
+}
+$this->RedirectToAdminTab();
 
 ?>
\ No newline at end of file
