@@ -80,26 +80,10 @@ $smarty->assign('uploaddirectory_input',$this->CreateInputText($id,'uploaddirect
 							       $this->GetPreference('uploaddirectory',$config['uploads_path']),
 							       30));
 
-$val = $this->GetPreference('uploadfiletypes','jpg,JPG,gif,GIF');
+$val = $this->GetPreference('uploadfiletypes','jpg,jpeg,gif,png');
 $smarty->assign('uploadfiletypes_text',$this->Lang('uploadfiletypes'));
 $smarty->assign('uploadfiletypes_input',$this->CreateInputText($id,'uploadfiletypes',$val, 30));
 
-$val = $this->GetPreference('thumb_width',180);
-$smarty->assign('thumb_width_text',$this->Lang('thumb_width'));
-$smarty->assign('thumb_width_input',$this->CreateInputText($id,'thumb_width',$val, 5));
-
-$val = $this->GetPreference('thumb_height',180);
-$smarty->assign('thumb_height_text',$this->Lang('thumb_height'));
-$smarty->assign('thumb_height_input',$this->CreateInputText($id,'thumb_height',$val, 5));
-
-$val = $this->GetPreference('large_width',500);
-$smarty->assign('large_width_text',$this->Lang('large_width'));
-$smarty->assign('large_width_input',$this->CreateInputText($id,'large_width',$val, 5));
-
-$val = $this->GetPreference('large_height',500);
-$smarty->assign('large_height_text',$this->Lang('large_height'));
-$smarty->assign('large_height_input',$this->CreateInputText($id,'large_height',$val, 5));
-
 $val = $this->GetPreference('uploadunique',1);
 $smarty->assign('uploadunique_text',$this->Lang('uploadunique'));
 $smarty->assign('uploadunique_input',
