@@ -66,20 +66,6 @@ if( !is_array($events) || count($events) != 1 ) {
 }
 $event = $events[0];
 
-/*
-$userops = $gCms->GetUserOperations();
-$userlist = $userops->LoadUsers();
-// print_r($userlist);
-$users = array();
-foreach ($userlist as $oneuser) {
-  $users[$oneuser->id] = $oneuser;
-}
-if( isset($users[$event['event_created_by']]) ) {
-  $event['author'] = $users[$event['event_created_by']]->username;
-  $event['authorname'] = $users[$event['event_created_by']]->firstname.' '.$users[$event['event_created_by']]->lastname;
-}
-*/
-
 $month_names = $this->GetMonthNames();
 
 // other language fields
