@@ -1,6 +1,12 @@
 <?php
 # Simple Language file for the Calendar module.
 # Copyright (c) 2004 by Rob Allen <rob@akrabat.com>
+$lang['title_recurring_event'] = 'This is a recurring event with children';
+$lang['title_child_event'] = 'This is a recurrance of a parent event';
+$lang['error_somedeleted'] = 'Some of the events were deleted.  However, due to permissions some were not';
+$lang['error_nonedeleted'] = 'Due to permissions or other errors, none of the selected events were deleted';
+$lang['error_deletefailed'] = 'Event deletion failed';
+$lang['fileattachment'] = 'File Attachment';
 $lang['prompt_general_settings'] = 'General Settings';
 $lang['prompt_editing_settings'] = 'Event Editing Settings';
 $lang['prompt_feedit_settings'] = 'Frontend Editing Settings';
@@ -138,7 +144,7 @@ $lang['last_page'] = '&gt;&gt;';
 $lang['page_of'] = 'Page %d of %d';
 $lang['search_results'] = 'Calendar Search Results';
 $lang['search_words'] = 'Search Words';
-$lang['no_results_found'] = 'No results found matching the query specified';
+$lang['no_results_found'] = 'No displayable events found for this period.';
 $lang['frequency'] = 'Frequency';
 $lang['specified_date'] = 'Use the specified date';
 $lang['first_sunday'] = 'First Sunday of the Month';
@@ -450,11 +456,11 @@ $lang['importtemplate'] = 'Import Template';
 $lang['template_deleted'] = 'The template was successfully deleted from the database.';
 $lang["updatetemplatesuccess"]="The template was updated successfully";
 $lang["updatetemplatefailure"]="An error occurred updating the template";
-$lang["settingssaved"]="Settings was saved successfully";
+$lang["settingssaved"]="Settings were saved successfully";
 $lang["categorydeleted"]="Category deleted";
 $lang["categoryupdated"]="Category updated";
 $lang["categoryadded"]="Category added";
-$lang["eventdeleted"]="The event was deleted";
+$lang["eventdeleted"]="Event(s) deleted successfully";
 $lang["eventupdated"]="The event was updated";
 $lang['default_page_error'] = 'Error: You must set a default page in order to use Calendar with pretty URLs turned on. Please go to the Calendar settings tab and choose one.';
 $lang["time_at"]="at";
@@ -475,10 +481,6 @@ $lang['defaultcalendarpage'] = 'Default event view page';
 $lang['uploaddirectory'] = 'Directory where file uploads should be placed';
 $lang['uploadfiletypes'] = 'Allowed file types';
 $lang['uploadunique'] = 'Ensure unique filenames';
-$lang['thumb_width'] = 'Thumbnail Width';
-$lang['thumb_height'] = 'Thumbnail Height';
-$lang['large_width'] = 'Large Image Width';
-$lang['large_height'] = 'Large Image Height';
 
 $lang['cal_recur_period'] = 'Recurs';
 $lang['cal_recur_until'] = 'Recurs Until';
