@@ -1,10 +1,34 @@
 <?php
-$lang['error_feu_loggedin'] = 'cet utilisateur n&#039;est pas connect&eacute; &agrave; FEU. Ajouter ou modifier les &eacute;v&eacute;nements n&#039;est pas permis.';
+$lang['prompt_general_settings'] = 'Param&egrave;tres globaux';
+$lang['prompt_editing_settings'] = 'Param&egrave;tres d&#039;&eacute;dition d&#039;&eacute;v&eacute;nements';
+$lang['prompt_feedit_settings'] = 'Param&egrave;tres d&#039;&eacute;dition de la partie publique du site (frontend)';
+$lang['prev_month'] = 'Aller au mois pr&eacute;c&eacute;dent';
+$lang['next_month'] = 'Aller au mois suivant';
+$lang['info_customfields_tab'] = 'Les champs personnalis&eacute;s peuvent &ecirc;tre r&eacute;ordonn&eacute;s en glissant / d&eacute;posant les lignes. La recherche n&#039;est possible que dans les champs texte, et seuls les zones de texte peuvent avoir des champs WYSIWYG li&eacute;s. <strong style=&quot;color: red;&quot;>Note:</strong> Les champs WYSIWYG ne seront pas affich&eacute;s pour les zones de texte sur la partie publique du site (frontend).';
+$lang['msg_categories_updated'] = 'Cat&eacute;gories mises &agrave; jour';
+$lang['msg_fieldsupdated'] = 'D&eacute;finitions de champ mises &agrave; jour';
+$lang['wysiwyg'] = 'WYSIWYG';
+$lang['info_reorder_categories'] = 'L&#039;ordre des cat&eacute;gories peut-&ecirc;tre d&eacute;fini en glissant / d&eacute;posant les lignes';
+$lang['error_categorynamerow'] = 'Le nom a &eacute;t&eacute; effac&eacute; pour une cat&eacute;gorie valide &agrave; la ligne&nbsp;:';
+$lang['confirm_nocategories'] = 'Nous n&#039;avons d&eacute;tect&eacute; aucune cat&eacute;gorie valide. &Ecirc;tes-vous s&ucirc;r que c&#039;est bien ce que vous voulez faire ?';
+$lang['add_field'] = 'Ajouter un champ';
+$lang['add_category'] = 'Ajouter une cat&eacute;gorie';
+$lang['prompt_firstdayofweek'] = 'Premier jour de la semaine';
+$lang['edit_event'] = '&Eacute;diter l&#039;&eacute;v&eacute;nement';
+$lang['edit_parent_event'] = '&Eacute;diter l&#039;&eacute;v&eacute;nement parent';
+$lang['title_child_event'] = 'C&#039;est un enfant d&#039;un &eacute;v&eacute;nement parent r&eacute;current';
+$lang['select_period'] = 'P&eacute;riode';
+$lang['show_filter'] = 'Montrer le filtre';
+$lang['show_filter_applied'] = 'Montrer le filtre <em>(appliqu&eacute;)</em>';
+$lang['reset'] = 'Remettre &agrave; z&eacute;ro';
+$lang['cal_current'] = 'Cette p&eacute;riode';
+$lang['cal_from'] = 'De';
+$lang['error_feu_loggedin'] = 'Cet utilisateur n&#039;est pas connect&eacute; &agrave; FEU. Ajouter ou modifier les &eacute;v&eacute;nements n&#039;est pas permis.';
 $lang['prompt_friendlyname'] = 'Nom &quot;convivial&quot; pour ce module dans la navigation de l&#039;administration';
 $lang['info_friendlyname'] = 'Note : Il se peut que vous ayez &agrave; vider le cache du site pour que cette pr&eacute;f&eacute;rence prenne effet. Si aucune valeur n&#039;est fournie, une valeur par d&eacute;faut sera utilis&eacute;e.';
 $lang['use_wysiwyg'] = 'Utilise le Wysiwyg';
 $lang['error_insufficientparams'] = 'Param&egrave;tres insuffisants';
-$lang['column_delimiter'] = 'Import file column delimiter';
+$lang['column_delimiter'] = 'S&eacute;parateur de colonnes dans le fichier import&eacute;';
 $lang['import_completed'] = 'Importation termin&eacute;';
 $lang['num_imported'] = 'Nombre d&#039;&eacute;v&egrave;nements cr&eacute;&eacute;s: %d';
 $lang['import_lines'] = 'Nombre de lignes trait&eacute;es du fichier: %d';
@@ -67,7 +91,6 @@ $lang['info_dflt_starttime'] = '<em>(S&#039;applique uniquement si les nouveaux
 $lang['search_type'] = 'Type de recherche';
 $lang['search_any'] = 'renvoie le r&eacute;sultat sur n&#039;importe lequel des mots recherch&eacute;s';
 $lang['search_all'] = 'renvoie le r&eacute;sultat de recherche sur tous les mots recherch&eacute;s';
-$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Note :</span> les recherches ne peuvent &ecirc;tre utilis&eacute;es que dans les champs de texte. Cocher les autres types de champ n&#039;aura aucun effet sur la recherche.';
 $lang['searchable'] = 'Utilisable comme crit&egrave;re de recherche';
 $lang['help_param_editeventtemplate'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier un autre gabarit d&#039;&eacute;dition d&#039;&eacute;v&eacute;nement (invoqu&eacute; lorsque l&#039;utilisateur cr&eacute;e ou &eacute;dite un &eacute;v&eacute;nement) que celui utilis&eacute; par d&eacute;faut.';
 $lang['help_param_editpage'] = 'Applicable uniquement pour l&#039;action Mes &Eacute;v&eacute;nements, ce param&egrave;tre permet de sp&eacute;cifier une autre page pour le formulaire d&#039;&eacute;dition.';
@@ -163,15 +186,15 @@ $lang['info_sysdflt_search_template'] = 'Gabarit de formulaire de recherche par
 $lang['searchtemplate_addedit'] = 'Ajouter/Modifier un gabarit de formulaire de recherche';
 $lang['info_search_template_tab'] = 'La liste des gabarits qui sont disponibles pour le formulaire de recherche';
 $lang['cal_search_form_templates'] = 'Gabarits de formulaire de recherche';
-$lang['max'] = 'max ';
+$lang['max'] = 'max';
 $lang['times'] = 'fois';
-$lang['on'] = 'on ';
+$lang['on'] = 'on';
 $lang['areyousure_uninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir faire ceci ? Si vous poursuivez, vous aller effacer de mani&egrave;re d&eacute;finitive toutes les donn&eacute;es associ&eacute;es &agrave; ce module.';
 $lang['post_uninstall'] = 'Le module Calendrier (CG) a &eacute;t&eacute; d&eacute;sinstall&eacute; et tous les &eacute;v&eacute;nements et les informations de gabarit associ&eacute;s &agrave; ce module ont &eacute;t&eacute; supprim&eacute;s.';
 $lang['fieldupdated'] = 'Champ mis &agrave; jour.';
 $lang['every'] = 'Tous les';
 $lang['or'] = 'ou';
-$lang['update_children'] = 'Mettre &agrave; jour les sous-&eacute;v&eacute;nement associ&eacute;s';
+$lang['update_children'] = 'Mettre &agrave; jour les sous-&eacute;v&eacute;nements associ&eacute;s';
 $lang['error_nocategory'] = 'Vous devez s&eacute;lectionner au moins une cat&eacute;gorie.';
 $lang['error_nothingselected'] = 'Rien n&#039;a &eacute;t&eacute; s&eacute;lectionn&eacute; pour l&#039;effacement.';
 $lang['error_eventoverlap'] = 'Vos param&egrave;tres de r&eacute;p&eacute;tition d&#039;&eacute;v&eacute;nement engendrent un chevauchement d&#039;&eacute;v&eacute;nements.';
@@ -190,7 +213,7 @@ $lang['abbr_tuesday'] = 'Ma';
 $lang['abbr_wednesday'] = 'Me';
 $lang['abbr_thursday'] = 'Je';
 $lang['abbr_friday'] = 'Ve';
-$lang['abbr_saturday'] = 'Sa ';
+$lang['abbr_saturday'] = 'Sa';
 $lang['weekdays'] = 'Jours de la semaine';
 $lang['plural_daily'] = 'Jours';
 $lang['plural_weekly'] = 'Semaines';
@@ -208,9 +231,9 @@ $lang['max_recur_events'] = 'Nombre maximum de sous-&eacute;v&eacute;nements';
 $lang['use_to_date'] = 'Sp&eacute;cifier une date de fin diff&eacute;rente ?';
 $lang['cancel'] = 'Annuler';
 $lang['show_child_events'] = 'Afficher les sous-&eacute;v&eacute;nements <em>(peut causer un affichage tr&egrave;s long)</em>';
-$lang['n/a'] = 'n/a ';
+$lang['n/a'] = 'n/a';
 $lang['recurs_until'] = 'R&eacute;p&eacute;tition jusqu&#039;&agrave;';
-$lang['parent'] = 'Parent ';
+$lang['parent'] = 'Parent';
 $lang['recur_period'] = 'P&eacute;riode de r&eacute;p&eacute;tition';
 $lang['filter'] = 'Filtre';
 $lang['start_date'] = 'Date de d&eacute;but';
@@ -244,8 +267,7 @@ $lang['eventhelp-EventAdded'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;neme
 <li>\&quot;event_date_end\&quot; - Date et heure de la fin de l&#039;&eacute;v&eacute;nement</li>
 <li>\&quot;event_created_by\&quot; - Le userid de l&#039;auteur</li>
 <li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-EventEdited'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nement de calendrier est &eacute;dit&eacute;.</p>
 <h4>Param&egrave;tres</h4>
 <ul>
@@ -256,36 +278,31 @@ $lang['eventhelp-EventEdited'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nem
 <li>\&quot;event_date_end\&quot; - Date et heure de la fin de l&#039;&eacute;v&eacute;nement</li>
 <li>\&quot;event_created_by\&quot; - Le userid de l&#039;auteur</li>
 <li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-EventDeleted'] = '<p>Envoy&eacute; quand un &eacute;v&eacute;nement de calendrier est supprim&eacute;.</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>\&quot;event_id\&quot; - L&#039;id de l&#039;&eacute;v&eacute;nement</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-CategoryAdded'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est ajout&eacute;e.</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-CategoryEdited'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est &eacute;dit&eacute;e.</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
 <li>\&quot;category_name\&quot; - Le nom de la cat&eacute;gorie</li>
 <li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
-</ul>
-';
+</ul>';
 $lang['eventhelp-CategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gorie de calendrier est supprim&eacute;e.</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>\&quot;category_id\&quot; - L&#039;id de la cat&eacute;gorie</li>
 <li>\&quot;category_name\&quot; - Le nom de la cat&eacute;gorie</li>
 <li>\&quot;category_order\&quot; - L&#039;ordre de tri de la cat&eacute;gorie</li>
-</ul>
-';
+</ul>';
 $lang['error_csv_insert'] = 'Erreur durant l&#039;importation des &eacute;v&egrave;nements depuis le css &agrave; la ligne %d';
 $lang['error_csvfirstlinefldnotfound'] = 'Un champs obligatoire: %s, n&#039;a pu &ecirc;tre trouv&eacute; dans la ligne d&#039;ent&ecirc;te du fichier csv';
 $lang['error_csvinvalidfirstline'] = 'Ne peut trouver une ligne d&#039;ent&ecirc;te valide dans le fichier CSV';
@@ -299,7 +316,7 @@ $lang['error_fileexists'] = 'ERREUR&nbsp;: Un fichier avec le m&ecirc;me nom exi
 $lang['error_csvfilenotfound'] = 'ERREUR&nbsp;: Impossible de trouver le fichier CSV';
 $lang['error_cantopenfile'] = 'ERREUR&nbsp;: Impossible d&#039;ouvrir le fichier';
 $lang['error_categoryexists'] = 'ERREUR&nbsp;: Une cat&eacute;gorie avec le nom %s existe d&eacute;j&agrave;';
-$lang['cal_id'] = 'Id ';
+$lang['cal_id'] = 'Id';
 $lang['cal_calendar'] = 'Calendrier (CG)';
 $lang['cal_default_templates'] = 'Gabarits par d&eacute;faut';
 $lang['cal_description'] = 'Ajout, &eacute;dition et suppression d&#039;&eacute;v&eacute;nements';
@@ -350,7 +367,7 @@ $lang['cal_december'] = 'D&eacute;cembre';
 $lang['cal_add'] = 'Ajout';
 $lang['cal_update'] = 'Mise &agrave; jour';
 $lang['cal_event'] = '&Eacute;v&eacute;nement';
-$lang['cal_date'] = 'Date ';
+$lang['cal_date'] = 'Date';
 $lang['cal_summary'] = 'Sommaire';
 $lang['cal_details'] = 'D&eacute;tails';
 $lang['cal_more'] = 'plus >>';
@@ -408,7 +425,7 @@ $lang['eventdeleted'] = 'L&#039;&eacute;v&eacute;nement a &eacute;t&eacute; supp
 $lang['eventupdated'] = 'L&#039;&eacute;v&eacute;nement a &eacute;t&eacute; mis &agrave; jour';
 $lang['default_page_error'] = 'Erreur&nbsp;: Vous devez d&eacute;finir une page par d&eacute;faut pour utiliser le calendrier lorsque &quot;pretty URLs&quot; est activ&eacute;. Veuillez aller &agrave; l&#039;onglet des param&egrave;tres du calendrier et d&eacute;finir une page par d&eacute;faut.';
 $lang['time_at'] = '&agrave;';
-$lang['type'] = 'Type ';
+$lang['type'] = 'Type';
 $lang['name'] = 'Nom';
 $lang['order'] = 'Ordre';
 $lang['fieldadded'] = 'Champ ajout&eacute; avec succ&egrave;s';
@@ -428,8 +445,6 @@ $lang['large_height'] = 'Hauteur de l&#039;image en grande taille';
 $lang['cal_recur_period'] = 'R&eacute;p&eacute;tition';
 $lang['cal_recur_until'] = 'R&eacute;p&egrave;te jusqu&#039;&agrave;';
 $lang['help_template'] = '<p><b>Affiche le nom de l&#039;auteur :</b></p>
-<code>Auteur : {$event.authorname}</code>
-';
-$lang['utma'] = '156861353.3775108633884901000.1235391363.1296071805.1296172731.93';
-$lang['qca'] = 'P0-186310954-1257243985177';
+<code>Auteur : {$event.authorname}</code>';
+$lang['qca'] = 'P0-483686814-1251229608352';
 ?>
\ No newline at end of file
