@@ -1,4 +1,5 @@
 <?php
+$lang['error_feu_loggedin'] = 'Brukeren er ikke logget inn i FEU. Legge til eller redigere hendelser er ikke tillatt';
 $lang['prompt_friendlyname'] = 'Vennlig navn for denne modulen i admin menyen';
 $lang['info_friendlyname'] = 'Merk: Du vil kanskje trenge &aring; t&oslash;mme nettstedets mellomlager for at denne innstillingen skal f&aring; effekt. Om ingen verdi er oppgitt s&aring; vil en standard benyttes.';
 $lang['use_wysiwyg'] = 'Benytt Wysiwyg';
@@ -429,9 +430,8 @@ $lang['cal_recur_until'] = 'Gjentas inntil';
 $lang['help_template'] = '<p><b>Skriv Opphavsmann navn:</b></p>
 <code>Opphavsmann: {$event.authorname}</code>
 ';
-$lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.578457877.1345846475.1346091347.1346097315.14';
-$lang['utmz'] = '156861353.1345846475.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.787464702.1355990775.1356957719.1357824154.4';
+$lang['utmz'] = '156861353.1355990775.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1783067311-1323366114110';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
