@@ -251,6 +251,8 @@ $this->CreateEvent('CategoryDeleted');
 
 // Permissions
 $this->CreatePermission('Modify Calendar', 'Modify Calendar');
+$this->CreatePermission('Add Calendar Events', 'Add Calendar Events');
+$this->CreatePermission('Edit My Calendar Events', 'Edit My Calendar Events');
 $this->CreatePermission('Manage Calendar Attributes','Manage Calendar Attributes');
 
 //Insert example stylesheet
