@@ -156,4 +156,10 @@ if( version_compare($oldversion,'1.11.1') < 0 ) {
   $sqlarray = $dict->DropColumnSQL($this->fields_table_name,'field_searchable');
   $dict->ExecuteSQLArray($sqlarray);
 }
+
+if( version_compare($oldversion,'1.13') < 0 ) {
+  $this->CreatePermission('Add Calendar Events', 'Add Calendar Events');
+  $this->CreatePermission('Edit My Calendar Events', 'Edit My Calendar Events');
+}
+
 ?>
\ No newline at end of file
